@@ -19,6 +19,7 @@ from .exceptions import (
     FritzConnectionException,
     FRITZ_ERRORS,
 )
+from .logger import fritzlogger
 from .utils import localname
 
 
@@ -234,6 +235,8 @@ class Soaper:
         """
 
         def handle_response(response):
+            fritzlogger.log(f"response status: {response.status_code}", "debug")
+            fritzlogger.log(response.text, "debug")
             if response.status_code != 200:
                 raise_fritzconnection_error(response)
             return self.parse_response(response, service, action_name)
@@ -247,6 +250,8 @@ class Soaper:
         body = self.get_body(service, action_name, arguments)
         envelope = self.envelope.format(body=body).encode("utf-8")
         url = f"{self.address}:{self.port}{service.controlURL}"
+        fritzlogger.log(f"\n{url}", "debug")
+        fritzlogger.log(envelope, "debug")
         if self.session:
             with self.session.post(
                 url, data=envelope, headers=headers, timeout=self.timeout
