@@ -7,6 +7,7 @@ import requests
 
 from xml.etree import ElementTree as etree
 from .exceptions import FritzConnectionException
+from .logger import fritzlogger
 
 
 NS_REGEX = re.compile("({(?P<namespace>.*)})?(?P<localname>.*)")
@@ -28,12 +29,14 @@ def get_content_from(url, timeout=None, session=None):
     verification will fail.
     """
     def handle_response(response):
+        fritzlogger.log(response.text, "debug")
         ct = response.headers.get("Content-type")
         if ct == "text/html":
             message = f"Unable to retrieve resource '{url}' from the device."
             raise FritzConnectionException(message)
         return response.text
 
+    fritzlogger.log(f"\n{url}", "debug")
     if session:
         with session.get(url, timeout=timeout) as response:
             return handle_response(response)
