@@ -1,5 +1,17 @@
+"""
+Abstract base class for all library classes.
+"""
+# This module is part of the FritzConnection package.
+# https://github.com/kbr/fritzconnection
+# License: MIT (https://opensource.org/licenses/MIT)
+# Author: Klaus Bremer
 
-from ..core.fritzconnection import FritzConnection
+
+from ..core.fritzconnection import (
+    FritzConnection,
+    DEFAULT_POOL_CONNECTIONS,
+    DEFAULT_POOL_MAXSIZE,
+)
 
 
 class AbstractLibraryBase:
@@ -10,10 +22,14 @@ class AbstractLibraryBase:
     the ip of the Fritz!Box, `port` the port to connect to, `user` the
     username, `password` the password, `timeout` a timeout as floating
     point number in seconds, `use_tls` a boolean indicating to use TLS
-    (default False).
+    (default False). `pool_connections` and `pool_maxsize` are to
+    override the urllib3 default settings.
     """
     def __init__(self, fc=None, address=None, port=None, user=None,
-                 password=None, timeout=None, use_tls=False):
+                 password=None, timeout=None, use_tls=False,
+                 pool_connections=DEFAULT_POOL_CONNECTIONS,
+                 pool_maxsize=DEFAULT_POOL_MAXSIZE,
+        ):
         if fc is None:
             kwargs = {
                 k:v for k, v in locals().items() if k not in ('self', 'fc')
